<?php

if ( ! class_exists( 'SiteOrigin_Widget_Base_Slider' ) ) {
	include_once plugin_dir_path( SOW_BUNDLE_BASE_FILE ) . '/base/inc/widgets/base-slider.class.php';
}

class Restaurantz_Testimonial_Slider_Widget extends SiteOrigin_Widget_Base_Slider {

	function __construct() {

		$custom_control = $this->control_form_fields();
		$custom_control['nav_color_hex']['default'] = '#313131';
		$custom_control['show_pager'] = array(
				'type'    => 'checkbox',
				'label'   => __( 'Show Pager', 'restaurantz' ),
				'default' => 0,
		);

		parent::__construct(
			'restaurantz-testimonial-slider',
			__( 'Restaurantz: Testimonial Slider', 'restaurantz' ),
			array(
				'description' => __( 'Displays Testimonials as Slider.', 'restaurantz' ),
				'panels_title' => false,
			),
			array(),
			array(
				'title' => array(
					'type'  => 'text',
					'label' => __( 'Title', 'restaurantz' ),
				),
				'sub_title' => array(
					'type'  => 'text',
					'label' => __( 'Subtitle', 'restaurantz' ),
				),
				'frames' => array(
					'type'       => 'repeater',
					'label'      => __( 'Testimonials', 'restaurantz' ),
					'item_name'  => __( 'Testimonial', 'restaurantz' ),
					'item_label' => array(
						'selector'     => "[id*='frames-full_name']",
						'update_event' => 'change',
						'value_method' => 'val',
					),
					'fields' => array(
						'full_name' => array(
							'type'  => 'text',
							'label' => __( 'Full Name', 'restaurantz' ),
						),
						'position' => array(
							'type'  => 'text',
							'label' => __( 'Position', 'restaurantz' ),
						),
						'message' => array(
							'type'  => 'textarea',
							'label' => __( 'Message', 'restaurantz' ),
						),
						'profile_picture' => array(
							'type'     => 'media',
							'library'  => 'image',
							'label'    => __( 'Image', 'restaurantz' ),
							'fallback' => true,
						),
					),
				),
				'jetpack_testimonial' => array(
					'type'   => 'section',
					'label'  => __( 'Jetpack Testimonial', 'restaurantz' ),
					'hide'   => true,
					'fields' => array(
						'enable_jetpack_testimonial' => array(
							'type'        => 'checkbox',
							'label'       => __( 'Enable Jetpack Mode', 'restaurantz' ),
							'description' => __( 'Check this to display Jetpack Testimonials as slider.', 'restaurantz' ),
							'default'     => false,
						),
						'posts_number' => array(
							'type'    => 'number',
							'label'   => __( 'No of Testimonials', 'restaurantz' ),
							'default' => 4,
						),
					),
				),
				'controls' => array(
					'type'   => 'section',
					'label'  => __( 'Controls', 'restaurantz' ),
					'hide'   => false,
					'fields' => $custom_control,
				),
				'settings_color' => array(
					'type'   => 'section',
					'label'  => __( 'Color Settings', 'restaurantz' ),
					'hide' => true,
					'fields' => array(
						'color_widget_title' => array(
							'type'    => 'color',
							'label'   => __( 'Widget Title Color', 'restaurantz' ),
							'default' => '#562c19',
						),
						'color_widget_sub_title' => array(
							'type'    => 'color',
							'label'   => __( 'Widget Subtitle Color', 'restaurantz' ),
							'default' => '#313131',
						),
						'color_testimonial_content' => array(
							'type'    => 'color',
							'label'   => __( 'Testimonial Content Color', 'restaurantz' ),
							'default' => '#313131',
						),
						'color_arrow_hover' => array(
							'type'    => 'color',
							'label'   => __( 'Arrow Hover Color', 'restaurantz' ),
							'default' => '#f9a400',
						),
						'color_name' => array(
							'type'    => 'color',
							'label'   => __( 'Name Color', 'restaurantz' ),
							'default' => '#f9a400',
						),
						'color_position' => array(
							'type'    => 'color',
							'label'   => __( 'Position Color', 'restaurantz' ),
							'default' => '#f9a400',
						),
						'color_pager' => array(
							'type'    => 'color',
							'label'   => __( 'Pager Color', 'restaurantz' ),
							'default' => '#313131',
						),
						'color_pager_active' => array(
							'type'    => 'color',
							'label'   => __( 'Pager Active Color', 'restaurantz' ),
							'default' => '#f9a400',
						),
	    			),
				),
			),
			plugin_dir_path( __FILE__ ) . '../'
		);
	}

	function render_frame_contents( $i, $frame ) {

		?>
		<div class="testimonial-item">
			<div class="testimonial-message">
				<?php $testimonial_message = wp_kses_post( $frame['message'] ); ?>
				<?php echo wp_kses_post( wpautop( $testimonial_message ) ); ?>
			</div><!-- .testimonial-message -->
			<?php
				$image = siteorigin_widgets_get_attachment_image_src( $frame['profile_picture'], 'thumbnail', $frame['profile_picture_fallback'] );
			?>
			<?php if ( ! empty( $image ) ) : ?>
				<div class="testimonial-thumb"><img src="<?php echo esc_url( $image[0] ); ?>" alt="<?php echo esc_attr( $frame['full_name'] ); ?>" /></div>
			<?php endif; ?>
			<div class="testimonial-person">
				<?php echo esc_html( $frame['full_name'] ); ?>
				<?php if ( ! empty( $frame['position'] ) ) : ?>
					<span class="position"><?php echo esc_html( $frame['position'] ); ?></span>
				<?php endif; ?>
			</div><!-- .testimonial-person -->
		</div><!-- .testimonial-item -->
		<?php

	}

	function get_template_name( $instance ) {
		return 'default';
	}

	function get_style_name( $instance ) {
		return 'default';
	}

	/**
	 * The less variables to control the design of the slider
	 *
	 * @param $instance
	 *
	 * @return array
	 */
	function get_less_variables( $instance ) {
		$less_vars = array();
		if ( ! empty( $instance['settings_color']['color_widget_title'] ) ) {
			$less_vars['color_widget_title'] = $instance['settings_color']['color_widget_title'];
		}
		if ( ! empty( $instance['settings_color']['color_widget_sub_title'] ) ) {
			$less_vars['color_widget_sub_title'] = $instance['settings_color']['color_widget_sub_title'];
		}
		if ( ! empty( $instance['settings_color']['color_testimonial_content'] ) ) {
			$less_vars['color_testimonial_content'] = $instance['settings_color']['color_testimonial_content'];
		}
		if ( ! empty( $instance['settings_color']['color_arrow_hover'] ) ) {
			$less_vars['color_arrow_hover'] = $instance['settings_color']['color_arrow_hover'];
		}
		if ( ! empty( $instance['settings_color']['color_name'] ) ) {
			$less_vars['color_name'] = $instance['settings_color']['color_name'];
		}
		if ( ! empty( $instance['settings_color']['color_position'] ) ) {
			$less_vars['color_position'] = $instance['settings_color']['color_position'];
		}
		if ( ! empty( $instance['settings_color']['color_pager'] ) ) {
			$less_vars['color_pager'] = $instance['settings_color']['color_pager'];
		}
		if ( ! empty( $instance['settings_color']['color_pager_active'] ) ) {
			$less_vars['color_pager_active'] = $instance['settings_color']['color_pager_active'];
		}
		if ( ! empty( $instance['controls']['nav_color_hex'] ) ) {
			$less_vars['nav_color_hex'] = $instance['controls']['nav_color_hex'];
		}
		if ( ! empty( $instance['controls']['nav_size'] ) ) {
			$less_vars['nav_size'] = $instance['controls']['nav_size'];
		}
		if ( ! empty( $instance['controls']['show_pager'] ) ) {
			$less_vars['show_pager'] = ( 1 === absint( $instance['controls']['show_pager'] ) ) ? 'yes' : 'no';
		}

		return $less_vars;

	}

	/**
	 * Change the instance to the new one we're using for sliders
	 *
	 * @param $instance
	 *
	 * @return mixed|void
	 */
	function modify_instance( $instance ) {

		if ( empty( $instance['controls'] ) ) {

			if ( ! empty( $instance['speed'] ) ) {
				$instance['controls']['speed'] = $instance['speed'];
			}
			if ( ! empty( $instance['timeout'] ) ) {
				$instance['controls']['timeout'] = $instance['timeout'];
			}
			if ( ! empty( $instance['nav_color_hex'] ) ) {
				$instance['controls']['nav_color_hex'] = $instance['nav_color_hex'];
			}
			if ( ! empty( $instance['nav_style'] ) ) {
				$instance['controls']['nav_style'] = $instance['nav_style'];
			}
			if ( ! empty( $instance['nav_size'] ) ) {
				$instance['controls']['nav_size'] = $instance['nav_size'];
			}

			unset( $instance['speed'] );
			unset( $instance['timeout'] );
			unset( $instance['nav_color_hex'] );
			unset( $instance['nav_style'] );
			unset( $instance['nav_size'] );
		}

		return $instance;

	}

	function get_testimonials_frames( $instance ) {

		$output = $instance['frames'];

		if ( isset( $instance['jetpack_testimonial']['enable_jetpack_testimonial'] ) && 1 === absint( $instance['jetpack_testimonial']['enable_jetpack_testimonial'] ) ) {
			$jetpack_testimonials = array();

			$posts_number = 4;
			if ( isset( $instance['jetpack_testimonial']['posts_number'] ) && absint( $instance['jetpack_testimonial']['posts_number'] ) > 0 ) {
				$posts_number = absint( $instance['jetpack_testimonial']['posts_number'] );
			}
			$targs = array(
				'post_type'      => 'jetpack-testimonial',
				'posts_per_page' => $posts_number,
				'no_found_rows'  => true,
			);
			$all_posts = get_posts( $targs );
			if ( ! empty( $all_posts ) ) {
				$i = 0;
				foreach ( $all_posts as $t ) {
					$jetpack_testimonials[ $i ]['full_name']       = $t->post_title;
					$jetpack_testimonials[ $i ]['position']        = '';
					$jetpack_testimonials[ $i ]['message']         = $t->post_content;
					$jetpack_testimonials[ $i ]['profile_picture'] = absint( get_post_thumbnail_id( $t->ID ) );
					$i++;
				}
			}
			if ( ! empty( $jetpack_testimonials ) ) {
				$output = $jetpack_testimonials;
			}
		}
		return $output;

	}
}

siteorigin_widget_register( 'restaurantz-testimonial-slider', __FILE__, 'Restaurantz_Testimonial_Slider_Widget' );
